@@ -7,6 +7,8 @@ from qbittorrentapi.request import Request
 
 
 class LogPeersList(List):
+    """Response for :meth:`~LogAPIMixIn.log_peers`"""
+
     def __init__(self, list_entries=None, client=None):
         super(LogPeersList, self).__init__(
             list_entries, entry_class=LogPeer, client=client
@@ -14,10 +16,12 @@ class LogPeersList(List):
 
 
 class LogPeer(ListEntry):
-    pass
+    """Item in :class:`LogPeersList`"""
 
 
 class LogMainList(List):
+    """Response to :meth:`~LogAPIMixIn.log_main`"""
+
     def __init__(self, list_entries=None, client=None):
         super(LogMainList, self).__init__(
             list_entries, entry_class=LogEntry, client=client
@@ -25,7 +29,7 @@ class LogMainList(List):
 
 
 class LogEntry(ListEntry):
-    pass
+    """Item in :class:`LogMainList`"""
 
 
 class Log(ClientCache):
@@ -49,6 +53,7 @@ class Log(ClientCache):
         self.main = Log._Main(client=client)
 
     def peers(self, last_known_id=None, **kwargs):
+        """Implements :meth:`~LogAPIMixIn.log_peers`"""
         return self._client.log_peers(last_known_id=last_known_id, **kwargs)
 
     class _Main(ClientCache):
@@ -110,7 +115,15 @@ class Log(ClientCache):
 
 
 class LogAPIMixIn(Request):
-    """Implementation of all Log API methods."""
+    """
+    Implementation of all Log API methods.
+
+    :Usage:
+        >>> from qbittorrentapi import Client
+        >>> client = Client(host='localhost:8080', username='admin', password='adminadmin')
+        >>> client.log_main(info=False)
+        >>> client.log_peers()
+    """
 
     @property
     def log(self):
@@ -143,7 +156,7 @@ class LogAPIMixIn(Request):
         :param warning: False to exclude 'warning' entries
         :param critical: False to exclude 'critical' entries
         :param last_known_id: only entries with an ID greater than this value will be returned
-        :return: List of log entries.
+        :return: :class:`LogMainList`
         """
         parameters = {
             "normal": normal,
@@ -163,7 +176,7 @@ class LogAPIMixIn(Request):
         Retrieve qBittorrent peer log.
 
         :param last_known_id: only entries with an ID greater than this value will be returned
-        :return: list of log entries in a List
+        :return: :class:`LogPeersList`
         """
         parameters = {"last_known_id": last_known_id}
         return self._get(
